@@ -1,4 +1,4 @@
-/* $Id: sem_limits.h,v 1.22 2003/10/20 15:19:39 hadess Exp $ */
+/* $Id: sem_limits.h,v 1.23 2003/10/20 20:11:58 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -46,7 +46,7 @@ typedef struct _glibtop_sem_limits	glibtop_sem_limits;
 
 struct _glibtop_sem_limits
 {
-	u_int64_t	flags,
+	guint64	flags,
 		semmap,		/* GLIBTOP_IPC_SEMMAP	*/
 		semmni,		/* GLIBTOP_IPC_SEMMNI	*/
 		semmns,		/* GLIBTOP_IPC_SEMMNS	*/
