@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.28 2004/07/17 12:01:24 bdejean Exp $ */
+/* $Id: netload.c,v 1.30 2004/07/22 13:52:59 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -385,7 +385,7 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
 			    break;
 	    }
 
-	    if(!ifr6) return;
+	    if(!ifr6) goto free_ipv6;
 
 	    memcpy(buf->address6,
 		   &((struct sockaddr_in6 *) ifr6->ifa_addr)->sin6_addr,
@@ -416,7 +416,9 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
 	    else
 		    buf->scope6 = GLIBTOP_IF_IN6_SCOPE_UNKNOWN;
 
-
 	    buf->flags |= _glibtop_sysdeps_netload_6;
+
+    free_ipv6:
+	    freeifaddrs(ifa0);
     } /* IPV6 */
 }
